@@ -1,5 +1,5 @@
-__version__ = "6.0.4"
-__version_info__ = (6, 0, 4, "", "")
+__version__ = "6.2.1"
+__version_info__ = (6, 2, 1, "", "")
 
 # PYSIDE-932: Python 2 cannot import 'zipfile' for embedding while being imported, itself.
 # We simply pre-load all imports for the signature extension.
@@ -22,7 +22,7 @@ import keyword
 import functools
 import typing
 
-from .shiboken6 import *
+from shiboken6.Shiboken import *
 
 # Trigger signature initialization via __builtins__.
 _init_pyside_extension()
